@@ -11,7 +11,7 @@ from retico_core.audio import (
     AudioDispatcherModule,
     AudioRecorderModule,
 )
-from retico_core.debug import DebugModule, CallbackModule
+from retico_core.debug import DebugModule, CallbackModule, TextPrinterModule
 from retico_core.dialogue import DialogueActRecorderModule, DialogueActTriggerModule
 from retico_core.text import (
     TextRecorderModule,
@@ -24,3 +24,9 @@ from retico_core.text import (
 from retico_googleasr import GoogleASRModule
 
 from retico_googletts import GoogleTTSModule
+
+from retico_wav2vecasr import Wav2VecASRModule
+
+from retico_speechbraintts import SpeechBrainTTSModule
+
+from retico_hftranslate import HFTranslateModule
